@@ -2,7 +2,7 @@
 package Test::Expander;
 
 # The versioning is conform with https://semver.org
-our $VERSION = '2.1.2';                                     ## no critic (RequireUseStrict, RequireUseWarnings)
+our $VERSION = '2.1.3';                                     ## no critic (RequireUseStrict, RequireUseWarnings)
 
 use strict;
 use warnings
@@ -163,7 +163,12 @@ sub _determine_testee {
     my $testee        = path( $test_file )->relative( $test_root )->parent;
     $options->{ -target } = $testee =~ s{/}{::}gr if grep { path( $_ )->child( $testee . '.pm' )->is_file } @INC;
   }
-  $CLASS = $options->{ -target } if exists( $options->{ -target } );
+  if ( defined( $options->{ -target } ) ) {
+    $CLASS = $options->{ -target };
+  }
+  else {
+    delete( $options->{ -target } );
+  }
 
   return $options;
 }
@@ -250,8 +255,8 @@ sub _parse_options {
       $DIE->( $FMT_INVALID_VALUE, $option_name, $option_value ) if ref( $option_value );
       $METHOD = $options->{ $option_name } = $option_value;
     }
-    elsif ( $option_name eq '-target' ) {                 # Do not load module only if its name is undef
-      $options->{ $option_name } = $option_value if defined( $option_value );
+    elsif ( $option_name eq '-target' ) {
+      $options->{ $option_name } = $option_value;
     }
     elsif ( $option_name eq '-tempdir' ) {
       $DIE->( $FMT_INVALID_VALUE, $option_name, $option_value ) if ref( $option_value ) ne 'HASH';
